![Image tests](https://travis-ci.com/yaricp/py-solarhouse.svg?branch=master)

[![Documentation](https://readthedocs.org/projects/py-solarhouse/badge/?version=latest&style=flat)](https://py-solarhouse.readthedocs.io/en/latest/)
[![License](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)